print("Root Normal")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(truncnorm)



# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Mueller.csv")

error <- function(p=c(10, 3), quantiles, exp){
  gx <- qtruncnorm(p=quantiles, a = 0, b = Inf, mean=p[1], sd=p[2])
  sum(abs((gx-exp)))
}

quants <- c(0.25, 0.5, 0.75)
l = length(O$N)


# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq', 'truncnorm', 'data.table')) %dopar%  {
  
  q = as.numeric(O[i , 4:6]/1000)
  q = q^2
  solution <- nlm(f=error, p= c(0.5, 0.3), quantiles = quants, exp=q)
  
  x = rtruncnorm(10^5, a = 0, b = Inf, solution$estimate[1], solution$estimate[2])
  x = sqrt(x)
  
  gini = ineq(x)
  mean = mean(x)
  
  test = (qtruncnorm(quants, a = 0, b = Inf, solution$estimate[1], solution$estimate[2]))^0.5
  test = t(test)


  data.table(gini, mean, test, type = "Sqrt Norm", solution$estimate[1], solution$estimate[2], NA, NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Sqrt Norm Results.csv")






  


