library(readr)
library(ineq)
library(data.table)
library(magrittr)
library(here)

dir = here()

  d = read.csv("BGH.csv")
  d = data.table(Year = d$year, Level = d$level, Pay = d$salary) %>% na.omit()
  d$Year = paste("19", d$Year, sep = "")
  d$Year = as.numeric(d$Year)

# remove BGH outlier years
  remove = c(1986, 1987, 1988)
  d = subset(d, !Year %in% remove)


  gini.adjust = function(x){
      ifelse(length(x) == 1, 0, ineq(x)*length(x)/(length(x) -1))
    
  }
  
  
  # analysis by year and by level
  
  result = d[ ,list(
            N = length(Pay),
            Mean = mean(Pay),
            Gini = gini.adjust(Pay),
            Source = "BGH"),
    by = .(Year, Level)       ]

  result = result[order(Year, Level), ]


write_csv(result, "BGH Level Results.csv")


