print("Log Logistic")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(FAdist)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Grund Merge.csv")


error <- function(p=c(1, 1), quantiles, exp){
  gx <- qllog(p=quantiles, shape  = p[1], scale = p[2])
  sum(abs((gx-exp)))
}

quants <- c(0.05, 0.95)
l = length(O$x)



bad = c(7707, 84)


# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq',  'data.table', 'FAdist')) %dopar%  {
  
  if(i %in% bad){
    mean = 0
    gini = 0
    test = t(rep(10^5, 5))
    
  }else{
    
  q = as.numeric(O[i , 4:5]/1000)
  solution <- nlm(f=error, p= c(5, 1), quantiles = quants, exp=q)

  sigma = solution$estimate[1]
  mu = solution$estimate[2]
  
  mean = exp(mu)*gamma(1+sigma)*gamma(1-sigma)
  gini = sigma
  
  test = qllog(quants, sigma, mu)
  missing = 5 - length(test)
test = c(test, rep(NA, missing))
test = t(test)


  }
  
  data.table(gini, mean, test, type = "Loglogistic", solution$estimate[1], solution$estimate[2], NA, NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Loglogistic Results.csv")





