print("Burr")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")


O = read_csv("Grund Merge.csv")


error <- function(p=c(10, 3), quantiles, exp){
  gx <- qburr(p=quantiles, shape1 = p[1], shape2 = p[2], scale = p[3])
  sum(abs((gx-exp)))
}

quants <- c(0.05, 0.95)
l = length(O$x)

# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq', 'actuar', 'data.table')) %dopar%  {

  q = as.numeric(O[i , 4:5]/1000)
  solution <- nlm(f=error, p= c(1,1,1), quantiles = quants, exp=q)
  
  x = rburr(10^5, shape1 = solution$estimate[1], shape2 = solution$estimate[2], scale = solution$estimate[3])

  gini = ineq(x)
  mean = mean(x)
  
  test =   qburr(quants, shape1 = solution$estimate[1], shape2 = solution$estimate[2], scale = solution$estimate[3])
  missing = 5 - length(test)
test = c(test, rep(NA, missing))
test = t(test)
  

  data.table(gini, mean, test, type = "Burr", solution$estimate[1],  solution$estimate[2], solution$estimate[3], NA)

}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Burr Results.csv")

