print("Log Gamma")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/
library(VGAM)
library(NORMT3)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(actuar)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Grund Merge.csv")

error <- function(p=c(10, 3), quantiles, exp){
  gx <- qlgamma(p=quantiles, shapelog = p[1], ratelog =  p[2])
  sum(abs((gx-exp)))
}

quants <- c(0.05, 0.95)
l = length(O$x)


# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq',  'data.table', 'actuar')) %dopar%  {
  
  q = as.numeric(O[i , 4:5]/1000)
  solution <- nlm(f=error, p= c(1, 1), quantiles = quants, exp=q)
  
  x = rlgamma(10^5, solution$estimate[1], solution$estimate[2])

  gini = ineq(x)
  mean = mean(x)
  
  test = qlgamma(quants, solution$estimate[1], solution$estimate[2])
  missing = 5 - length(test)
test = c(test, rep(NA, missing))
test = t(test)


  data.table(gini, mean, test, type = "Lgamma", solution$estimate[1], solution$estimate[2], NA, NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Lgamma Results.csv")







