print("GB2")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(GB2)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Treble_mean.csv")


error <- function(p=c(1, 1, 1, 1), quantiles, exp){
  gx <- qgb2(p=quantiles, shape1  = p[1], scale = p[2], shape2 = p[3], shape3 = p[4])
  sum(abs((gx-exp)))
}


quants <- c(0.05, 0.95)
l = length(O$x)



# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq',  'data.table', 'GB2')) %dopar%  {
  
  q = as.numeric(O[i , c(3,5)]/1000)
  solution <- nlm(f=error, p= c(1, 1, 1, 1), quantiles = quants, exp=q)
  
  shape1 = solution$estimate[1]
  scale = solution$estimate[2]
  shape2 = solution$estimate[3]
  shape3 = solution$estimate[4]
  
  gini = gini.gb2(shape1, shape2, shape3)
  
  x = rgb2(10^5, shape1, scale, shape2, shape3)
  mean = mean(x)
  
  test = qgb2(quants, shape1, scale, shape2, shape3)
  missing = 5 - length(test)
test = c(test, rep(NA, missing))
test = t(test)


  data.table(gini, mean, test, type = "GB2", solution$estimate[1], solution$estimate[2], solution$estimate[3], solution$estimate[4])
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Dagum Results.csv")




