library(readr)
library(magrittr)
library(data.table)
library(ineq)
library(here)

dir = here()
setwd(dir)

d = read_csv("case_studies.csv") %>% data.table 
d$ID = 1:length(d$Year)

d$Source =  d$Source %>%   
            gsub("BGH", "Baker et al.", .) %>%
            gsub("et al", "et al.", .) %>%
            gsub('[0-9]*', '' , .)



# analysis of main data

  sub.func = function(x){
         power =  cumsum(x)[-length(x)] / x[-1]
         power = c(1, power+1)
         return(power)    
    }


  pay.func = function(x){x/x[1]}

  subordinates = d[, .(power =   sub.func(N)), by = .(Source, Year )]
  pay.to.base  = d[, .(pay_norm =   pay.func(Mean)), by = .(Source, Year )]
  
  result = data.table(subordinates, pay_norm = pay.to.base$pay_norm) %>% na.omit

  d = data.table(d, power = subordinates$power, pay_norm = pay.to.base$pay_norm)

  
# add treble data

  N =  d[d$Source == "Treble et al. "] %>% 
    .[ , mean(N, na.rm = T), by = "Level"] %>%
    subset(. , is.finite(V1) == T )
  
  d[Source == "Treble et al. " & Year == "1989-1997", 3] = N$V1
    
  power =  d[d$Source == "Treble et al. "] %>% 
          .[ , mean(power, na.rm = T), by = "Level"] %>%
          subset(. , is.finite(V1) == T )
  
  
  d[Source == "Treble et al. " & Year == "1989-1997", 10] = power$V1
  
  d = subset(d, is.na(d$power) == F & is.na(d$pay_norm) == F)
  
# remove grund
  d = subset(d, Source != "Grund ")

# export
setwd(dir)
write_csv(d, "case_subordinates.csv")


