library(data.table)
library(here)

dir = here()
setwd(dir)

military = fread("military_rank_pay.csv")

# remove unknown ranks
unknown = grep("Unknown", military$rank)
military = military[-unknown]

# remove warrant officers
warrant = grep("W", military$rank)
military = military[-warrant]

# ranks in two columns and order by increasing rank
military$rank_letter = gsub("[0-9]", "", military$rank)
military$rank_number = gsub("[^0-9]", "", military$rank) %>% as.numeric()
military = military[order(year, rank_letter, rank_number)]

military$rank_letter[military$rank_letter == "E"] = "Enlisted"
military$rank_letter[military$rank_letter == "O"] = "Officer"

# mean pay by rank
military$mean_pay = (military$pay_lower + military$pay_upper) / 2

# normalize pay to bottom rank
fnorm = function(x){ x / x[1]}

mean_pay_norm = military[, fnorm(mean_pay), by = year]
military$mean_pay_norm = mean_pay_norm$V1

# hierarchical power
power_func = function(x){ 
  cumsum(x) / x
}

h_power = military[, power_func(number), by = year]

# years covered
years = paste("Years:", min(military$year), "-", max(military$year) )

# export
output = data.table(power = h_power$V1,
                    pay_norm = military$mean_pay_norm)

setwd(dir)
fwrite(output, "military_power.csv")




