
library(data.table)
library(here)
library(magrittr)

dir = here()
wd = paste(dir, "/raw", sep = "")
setwd(wd)

meta = fread("WDISeries.csv")
codes = fread("codes.csv")
country.only = fread("country_only_codes.csv")

d = fread("WDIData.csv", header = F)
info = d[1,] %>% t() %>% as.vector()

series.codes = d[,4] %>% t() %>% as.vector()
ids = which(series.codes %in% codes$code)

y = as.numeric(info) 
y = y[-c(1:4)]

keep = d[ids, ]

sub = keep[V4 == codes$code[1]]
n = ncol(sub)-4

country = rep(sub$V1, each = n)
country.code = rep(sub$V2, each = n)
year = rep(y, nrow(sub))

output = data.table(country, country.code, year)

for(i in 1:nrow(codes)){
  
  s.code = codes$code[i]
  
  sub = keep[V4 == s.code]
  
  values = sub[, 5:ncol(sub)] 
  long = values %>% t() %>% as.vector() %>% as.numeric()
  
  l = nrow(sub)
  
  if(l >0){
    output = cbind(output, long)
  }

  name = names(output)
  name = gsub("long", s.code, name)
  names(output) = name
  
}

# usa only
output = output[order(country.code, year),] #%>% na.omit()
#output = output[country.code == "USA"]

setwd(dir)
fwrite(output, "wdi.csv")




