library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)
library(hmod)

dir = here()
text.size = 10

#-------------------------------------------------------
# empirical

# data
setwd(dir)
setwd("../synthesis/beta")
beta = fread("beta.csv")
beta$source = as.factor(beta$source)
beta$source = reorder(beta$source, beta$beta, median)

# plot 
beta_plot = ggplot(data = beta) +
  geom_boxplot(aes(x = source, y = beta, fill = source), outlier.color = NA) +
  scale_y_continuous("Degree of hierarchical despotism (D)", breaks = seq(0, 2, 0.1)) +
  coord_cartesian(ylim = c(0.1, 1.2)) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = "none",
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5, size = rel(1)),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_blank(),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times"))
  

# export
setwd(dir)
gA = ggplotGrob(beta_plot)

png("beta_empirical.png", width = 5, height = 4.5, res = 600, units = "in")
grid.arrange(gA)
dev.off()
