library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)
library(hmod)

dir = here()
text.size = 10

# step function
setwd(dir)
source("bin_function.R")

# data
setwd(dir)
setwd("../synthesis/beta")
beta = fread("beta_kfrac.csv")
beta = beta[beta <= 1 & beta >= 0.2]

# binned analysis
result = bin_func(y = beta$beta, 
                  x = beta$k_frac,
                  adjust = 1.2,
                  lwr = 0.25,
                  upr = 0.75)

result = result
result$bin = result$bin*100

# plot 
beta_plot = ggplot() +
  geom_ribbon(data = result, aes(x = bin, ymin = lwr, ymax = upr, fill = "P25 - P75"),  
              alpha = 0.4) +
  geom_line(data = result, aes(x = bin, y = mid, col = "Median"), size = 1) +
  scale_x_continuous("Portion of CEO income earned from stock options (%)",
                     breaks = seq(0, 100, 10)) +
  scale_y_continuous("Degree of hierarchical despotism (D)") +
  scale_color_manual(values = "dodgerblue4") +
  scale_fill_manual(values = "dodgerblue4") +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.15, 0.8),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        legend.margin = margin(-0.5,0,0,0, unit="cm"),
        legend.box.margin=margin(c(-7,-10,-10,-10)),
        plot.title = element_text(face="bold", hjust = 0.5, size = rel(1)),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times"))

# export
setwd(dir)
gA = ggplotGrob(beta_plot)

png("beta_kfrac.png", width = 5, height = 4.5, res = 600, units = "in")
grid.arrange(gA)
dev.off()
