library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)
library(hmod)

dir = here()
text.size = 10

# model data
setwd(dir)
setwd("../model")
mod = fread("mod_results.csv")

# legend names
mod$type = string_replace("beta", "Hierarchical despotism (D)", mod$type)
mod$type = string_replace("size", "Hierarchy size", mod$type)
mod$type = string_replace("span", "Span of control", mod$type)

# plot
mod_plot = ggplot(data = mod) +
  geom_line(aes(x = scaled, y = gini, col = type), size = 1) +
  scale_x_continuous("Normalized scale",  breaks = seq(0, 1, 0.1)) +
  scale_y_continuous("Income inequality (Gini index)", breaks = seq(0, 1, 0.1)) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.25, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  annotate("text", 
          label = "A hierarchy with 100,000 members\nspan of control = 3\n0.1 ≤ D ≤ 1.1",
          x = 0.7, y = 0.82, size = 2.2, family = "Times") +
  annotate("text", 
          label = "A hierarchy with D = 0.5\nspan of control = 3\n1 ≤ size ≤ 100,000",
          x = 0.8, y = 0.42, size = 2.2, family = "Times") +
annotate("text", label = "A hierarchy with 100,000 members\nD = 0.5\n2 ≤ span of control ≤ 50",
          x = 0.55, y = 0.08, size = 2.2, family = "Times")

# export
setwd(dir)
gA = ggplotGrob(mod_plot)

png("hierarchy_effect_size.png", width = 5, height = 4.5, res = 600, units = "in")
grid.arrange(gA)
dev.off()


