library(hmod)
library(ineq)
library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)

dir = here()
text.size = 10

# empirical span
#----------------------------------------------

# data
setwd(dir)
setwd("../synthesis/span")
span = fread("span.csv")

# plot 
span_plot = ggplot(data = span) +
  geom_boxplot(aes(x = source, y = span, fill = source), outlier.color = NA) +
  scale_y_log10("Span of control") +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = "none",
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5, size = rel(1)),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_blank(),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times"))


# export
setwd(dir)
gA = ggplotGrob(span_plot)

png("span_empirical.png", width = 4.5, height = 4, res = 600, units = "in")
grid.arrange(gA)
dev.off()


