library(hmod)
library(here)
library(magrittr)

dir = here()
setwd(dir)

# beta function
get_beta = function(power, income){
  r = lm(log(income) ~ log(power))
  beta = coef(r)[2]
  return(beta)
}

#---------------------------------
# case studies
setwd(dir)
setwd("../../data/firm_case_studies")
case_study = fread("case_subordinates.csv")
beta_case = case_study[, get_beta(power, pay_norm), by = Source]
beta_case = data.table(beta = beta_case$V1, source = "Firm Case Studies")

#---------------------------------
# military
setwd(dir)
setwd("../../data/military")
military = fread("military_power.csv")
military$id = rep(1:14, each = 19)
beta_military = military[, get_beta(power, pay_norm), by = id]
beta_military = data.table(beta = beta_military$V1, source = "US Military")

#---------------------------------
# slaves
setwd(dir)
setwd("../../data/solomon")
slaves = fread("solomon_data.csv")
n_slaves = slaves$n_slaves %>% na.omit()

  # income
  planter_income = slaves$planter_income %>% na.omit()
  slave_expenses = slaves$slave_expenses %>% na.omit()

  n = 500
  beta_slaves = rep(NA, n)
  
  for(i in 1:n){
    slave_income_pc = slave_expenses/sample(n_slaves,1)
    planter_income_pc = sample(planter_income, 1) 
    
    planter_slave_income_ratio = planter_income_pc / slave_income_pc
    n_slave = sample(n_slaves, 1)
    
    planter_power = n_slave + 1 
    beta_slaves[i] = log(planter_slave_income_ratio) / log(planter_power)
  }

beta_slaves = data.table(beta = beta_slaves, source = "Cannon's Point Slave Estate")
  
  
#---------------------------------
# ceos
setwd(dir)
setwd("../../data/ceos")
ceo = fread("ceo_pay.csv")
span = mean(case_study$span, na.rm = T)
beta_ceo = rep(NA, nrow(ceo))

for(i in 1:nrow(ceo)){
    
    firm_size = ceo$Employees[i]
    h = hierarchy(firm_size, span)
    hp = hierarchical_power(h)
    pay_ratio_empirical = ceo$ceo_pay_ratio[i]
    
    error = function(beta){
      
      pay = hp^beta
      mean_pay = weighted_mean(pay, h)
      pay_ratio = max(pay) / mean_pay
      error = abs(pay_ratio - pay_ratio_empirical)
      return(error)
    }
    
    solution <- nlminb(start = 0.5,  error, lower = 0.0001, upper = 5, control = list(iter.max = 100))
    beta_ceo[i] = solution$par  

}

beta_ceo = data.table(beta = beta_ceo, source = "US CEOs")


#---------------------------------
# bind
output = rbind(beta_case,
               beta_slaves,
               beta_military,
               beta_ceo)



# export
setwd(dir)
fwrite(output, "beta.csv")

